@@ -9,7 +9,7 @@ use File::Find;
 use File::Spec;
 use Data::Dump qw( dump );
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 =pod
 
@@ -99,6 +99,11 @@ sub file_ok {
     $stat ||= [ stat($full_path) ];
     return 0 unless -r _;
     return 0 if -d _;
+    if (    $self->ok_if_newer_than
+        and $self->ok_if_newer_than >= $stat->[9] )
+    {
+        return 0;
+    }
     return 0
         if ( $self->_apply_file_rules($full_path)
         && !$self->_apply_file_match($full_path) );
@@ -274,6 +279,13 @@ sub get_doc {
     # might be faster since no OO overhead.
     my $type = SWISH::Prog::Utils->mime_type( $url, $ext );
 
+    if (    $self->ok_if_newer_than
+        and $self->ok_if_newer_than >= $stat->[9] )
+    {
+        warn "skipping $url ... too old\n";
+        return;
+    }
+
     return $self->doc_class->new(
         url     => $url,
         modtime => $stat->[9],
